##  Examples
Here are some example workspace views for typical use cases and scenarios.
Workspace View | Data
---|---
Application rationalization |  Fact sheets:
  * Type: application
  * Fact sheet subsection: Business Criticality & Functional Fit

Report: Application rationalization  Dashboard: Application rationalization
Application modernization |  Fact sheets:
  * Types: business capability, organization, application, interface, and IT component
  * Subsections for applications:
    * Business Criticality & Functional Fit
    * Technical Fit

Reports:
  * TIME portfolio report
  * Application roadmap report of the modernization


Application portfolio management (foundational relations working list) |  Fact sheet types: business capability, organization, and application Fact sheet filters:
  * Filter to applications without a relation to business capability and/or organization
  * Filter to applications without at least one responsible subscriber


Business unit view |  Fact sheet types: initiative, business capability, organization, application, and IT component Reports:
  * Business capability map report per business unit
  * Application landscape report per business unit - Initiative landscape for the business unit


Merger & Acquisition |  Fact sheet types: business capability, organization, application, IT component, and provider Reports:
  * Business capability map report per merging/carve-out unit
  * Application landscape report per merging/carve-out unit


ERP transformation | Fact sheet types: business capability, organization, application, and IT component
AI governance and adoption |  Fact sheets types and sections:
  * Application fact sheet:
    * Information
    * Governance
  * IT component fact sheet:
    * Information
    * Sourcing
  * Business capability fact sheet:
    * Information


Focus on an initiative |  Fact sheet type: initiative Reports:
  * Initiative roadmap
  * Initiative portfolio
  * Initiative matrix
  * Initiative landscape

Diagrams: Affected business capabilities diagram
Focus on the meta model changes | Include fact sheet details that were updated in the meta model configuration.


